@@ -106,13 +106,68 @@ CategoryManagerImpl
   private
   CategoryManagerImpl()
   {
-	super( TagType.TT_DOWNLOAD_CATEGORY, TagDownload.FEATURES, "Category" );
+	super( TagType.TT_DOWNLOAD_CATEGORY, TagDownload.FEATURES, "tag.type.category" );
 
 	addTagType();
 
   	loadCategories();
+  	
+  	MessageText.addListener((l1,l2)->{
+  		List<CategoryImpl>	cats;
+
+		try{
+			categories_mon.enter();
+
+			cats = new ArrayList<>(categories.values());
+
+		}finally{
+
+			categories_mon.exit();
+		}
+
+		try{
+			// buffer the changes to avoid costly multiple rebuilds of tagging UI components... 
+			setMDEventsEnabled( false );
+			
+			for ( CategoryImpl c: cats ){
+				c.localeChanged();
+			}
+			
+		}finally{
+			setMDEventsEnabled( true );
+		}
+  	});
   }
 
+  boolean	md_events_enabled = true;
+  List<Tag>	pending_md_events	= new ArrayList<>();
+  
+  private void
+  setMDEventsEnabled(
+	 boolean 	enabled )
+  {
+	  md_events_enabled = enabled;
+	  
+	  if ( enabled ){
+		  for ( Tag t: pending_md_events ){
+			  fireMetadataChanged(t);
+		  }
+		  pending_md_events.clear();
+	  }
+  }
+  
+  @Override
+  protected void 
+  fireMetadataChanged(
+	Tag  t)
+  {
+	  if ( md_events_enabled ){
+		  super.fireMetadataChanged(t);
+	  }else{
+		  pending_md_events.add( t );
+	  }
+	}
+  
   public void addCategoryManagerListener(CategoryManagerListener l) {
     category_listeners.addListener( l );
   }
