@@ -33,6 +33,7 @@ public final class ConfigKeys {
 		public static final String BCFG_BACKUP_NOTIFY = "br.backup.notify";
 		public static final String BCFG_RESTORE_AUTOPAUSE = "br.restore.autopause";
 		public static final String BCFG_BACKUP_PLUGINS = "br.restore.doplugins";
+		public static final String BCFG_BACKUP_PAUSE_DOWNLOADS = "br.backup.pause.downloads";
 	}
 
 	public static class Connection {
@@ -160,9 +161,12 @@ public final class ConfigKeys {
 		public static final String SCFG_RENAME_INCOMPLETE_FILES_EXTENSION = "Rename Incomplete Files Extension";
 		public static final String BCFG_ENABLE_SUBFOLDER_FOR_DND_FILES = "Enable Subfolder for DND Files";
 		public static final String SCFG_SUBFOLDER_FOR_DND_FILES = "Subfolder for DND Files";
+		public static final String BCFG_ENABLE_ALT_LOC_FOR_DND_FILES = "Enable Alternative Location for DND Files";
+		public static final String SCFG_ALT_LOC_FOR_DND_FILES = "Alternative Location for DND Files";
 		/** Despite name, this is the DND file prefix when SCFG_SUBFOLDER_FOR_DND_FILES is true */
 		public static final String BCFG_USE_INCOMPLETE_FILE_PREFIX = "Use Incomplete File Prefix";
 		public static final String BCFG_DOWNLOAD_HISTORY_ENABLED = "Download History Enabled";
+		public static final String BCFG_DOWNLOAD_HISTORY_DONT_ADD_DUP = "Download History Dont Add Duplicate";
 		public static final String BCFG_FILES_AUTO_TAG_ENABLE = "Files Auto Tag Enable";
 		public static final String ICFG_FILES_AUTO_TAG_COUNT = "Files Auto Tag Count";
 		public static final String SCFG_FILE_AUTO_TAG_NAME_DEFAULT = "File Auto Tag Name Default";
@@ -281,6 +285,7 @@ public final class ConfigKeys {
 	public static class Sharing {
 		public static final String SCFG_SHARING_PROTOCOL = "Sharing Protocol";
 		public static final String BCFG_SHARING_TORRENT_PRIVATE = "Sharing Torrent Private";
+		public static final String SCFG_SHARING_TORRENT_VERSION = "Sharing Torrent Version";
 		public static final String BCFG_SHARING_PERMIT_DHT = "Sharing Permit DHT";
 		public static final String BCFG_SHARING_ADD_HASHES = "Sharing Add Hashes";
 		public static final String BCFG_SHARING_DISABLE_RCM = "Sharing Disable RCM";
