@@ -133,25 +133,9 @@ FMFileAccessPieceReorderer
 
 				piece_size = (int)_torrent_file.getTorrent().getPieceLength();
 
-				TOTorrent	torrent = _torrent_file.getTorrent();
-
 				long	file_length	= _torrent_file.getLength();
 
-				long	file_offset_in_torrent = 0;
-
-				TOTorrentFile[] files = torrent.getFiles();
-
-				for (int i=0;i<files.length;i++){
-
-					TOTorrentFile	f = files[i];
-
-					if ( f == _torrent_file ){
-
-						break;
-					}
-
-					file_offset_in_torrent	+= f.getLength();
-				}
+				long	file_offset_in_torrent = _torrent_file.getOffsetInTorrent();
 
 				int first_piece_offset 	= (int)( file_offset_in_torrent % piece_size );
 
@@ -159,17 +143,15 @@ FMFileAccessPieceReorderer
 
 				long	file_end = file_offset_in_torrent + file_length;
 
-
 				last_piece_length = (int)( file_end - (( file_end / piece_size ) * piece_size ));
 
 				if ( last_piece_length == 0 ){
 
 					last_piece_length = piece_size;
 				}
-
 			}
 
-			dirt_state = FileUtil.newFile( control_dir, control_file ).exists()?DIRT_CLEAN:DIRT_NEVER_WRITTEN;
+			dirt_state = FileUtil.exists( FileUtil.newFile( control_dir, control_file ))?DIRT_CLEAN:DIRT_NEVER_WRITTEN;
 
 		}catch( Throwable e ){
 
@@ -1057,7 +1039,7 @@ FMFileAccessPieceReorderer
 
 		File	control_dir = config_file.getParentFile();
 
-		if ( !control_dir.exists()){
+		if ( !FileUtil.exists(control_dir )){
 
 			control_dir.mkdirs();
 		}
@@ -1066,6 +1048,8 @@ FMFileAccessPieceReorderer
 
 			throw( new FMFileManagerException( FMFileManagerException.OP_WRITE, "Failed to write control file " + config_file.getAbsolutePath()));
 		}
+		
+		FileUtil.existsWithCacheClear( control_dir );
 	}
 
 	private void
@@ -1080,7 +1064,7 @@ FMFileAccessPieceReorderer
 
 		Map	map = encodeConfig( storage_type, current_length, next_piece_index, piece_map );
 
-		if ( !control_dir.exists()){
+		if ( !FileUtil.exists( control_dir )){
 
 			control_dir.mkdirs();
 		}
@@ -1090,6 +1074,8 @@ FMFileAccessPieceReorderer
 			throw( new FMFileManagerException( FMFileManagerException.OP_WRITE, "Failed to write control file " + FileUtil.newFile( control_dir, control_file ).getAbsolutePath()));
 		}
 
+		FileUtil.existsWithCacheClear( control_dir );
+		
 		if ( TRACE ){
 			System.out.println( "WriteConfig: length=" + current_length + ", next=" + next_piece_index );
 		}
