@@ -48,7 +48,7 @@ FMFileImpl
 	protected static final String		READ_ACCESS_MODE	= "r";
 	protected static final String		WRITE_ACCESS_MODE	= "rw"; // "rwd"; - removing this to improve performance
 
-	private static final Map<String,List<Object[]>>			file_map 		= new HashMap<>();
+	private static final Map<StringInterner.FileKey,List<Object[]>>			file_map 		= new HashMap<>();
 	
 	private static final AEMonitor		file_map_mon	= new AEMonitor( "FMFile:map");
 
@@ -91,10 +91,10 @@ FMFileImpl
 	
 	private int					access_mode			= FM_READ;
 
-	private File				linked_file;
-	private long				last_modified;
-	private String				canonical_path;
-	private FileAccessor		fa;
+	private StringInterner.FileKey	linked_file;
+	private long					last_modified;
+	private StringInterner.FileKey	canonical_path;
+	private FileAccessor			fa;
 
 	private FMFileAccessController		file_access;
 
@@ -109,33 +109,37 @@ FMFileImpl
 
 	protected
 	FMFileImpl(
-		FMFileOwner			_owner,
-		FMFileManagerImpl	_manager,
-		File				_file,
-		int					_type,
-		boolean 			_force )
+		FMFileOwner				_owner,
+		FMFileManagerImpl		_manager,
+		StringInterner.FileKey	_file,
+		int						_type,
+		boolean 				_force )
 
 		throws FMFileManagerException
 	{
 		owner			= _owner;
 		manager			= _manager;
 
-		TOTorrentFile tf = owner.getTorrentFile();
-
-		linked_file		= manager.getFileLink( tf.getTorrent(), tf.getIndex(), _file );
+		linked_file		= owner.getFileLink( _file ); //  manager.getFileLink( tf.getTorrent(), tf.getIndex(), _file );
 
 		boolean	file_was_created	= false;
 		boolean	file_reserved		= false;
 		boolean	ok 					= false;
 
-		try{
+		File lf = linked_file.getFile();
 
-			String linked_path = linked_file.getPath();
+		try{			
+			String linked_path = lf.getPath();
 			try {
 
-				canonical_path = linked_file.getCanonicalPath();
-				if(canonical_path.equals(linked_path)) {
-					canonical_path = linked_path;
+				String cp = FileUtil.getCanonicalPath( lf, true );
+				
+				if ( cp.equals(linked_path)){
+					
+					canonical_path = linked_file;
+				}else{
+					
+					canonical_path = new StringInterner.FileKey( cp );
 				}
 
 			}catch( IOException ioe ) {
@@ -144,7 +148,7 @@ FMFileImpl
 
 		        if( msg != null && msg.contains("There are no more files")) {
 
-		          String abs_path = linked_file.getAbsolutePath();
+		          String abs_path = lf.getAbsolutePath();
 
 		          String error = "Caught 'There are no more files' exception during file.getCanonicalPath(). " +
 		                         "os=[" +Constants.OSName+ "], file.getPath()=[" + linked_path + "], file.getAbsolutePath()=[" +abs_path+ "]. ";
@@ -155,7 +159,7 @@ FMFileImpl
 		        throw ioe;
 			}
 
-			createDirs( linked_file );
+			createDirs( lf );
 
 			reserveFile();
 
@@ -169,7 +173,7 @@ FMFileImpl
 
 			if ( file_was_created ){
 
-				linked_file.delete();
+				lf.delete();
 			}
 
 			deleteDirs();
@@ -234,9 +238,17 @@ FMFileImpl
 	public boolean
 	exists()
 	{
-		return( linked_file.exists());
+		File lf = linked_file.getFile();
+		
+		return( FileUtil.exists( lf ));
 	}
 
+	protected File
+	getFile()
+	{
+		return( linked_file.getFile());
+	}
+	
 	@Override
 	public FMFileOwner
 	getOwner()
@@ -310,13 +322,13 @@ FMFileImpl
 	protected File
 	getLinkedFile()
 	{
-		return( linked_file );
+		return( linked_file.getFile());
 	}
 
 	@Override
 	public void
 	moveFile(
-		File						new_unlinked_file,
+		File						new_linked_file,
 		FileUtil.ProgressListener	pl )
 
 		throws FMFileManagerException
@@ -329,11 +341,11 @@ FMFileImpl
 			
 			length_cache = getLength();
 			
-			TOTorrentFile tf = owner.getTorrentFile();
-
 			String	new_canonical_path;
-
-			File	new_linked_file	= manager.getFileLink( tf.getTorrent(), tf.getIndex(), new_unlinked_file );
+				
+				// 3701 - switched the passed file to always be the actual destination regardless of any links, these are set up separately as required by callers
+				// TOTorrentFile tf = owner.getTorrentFile();
+				// File	new_linked_file	= manager.getFileLink( tf.getTorrent(), tf.getIndex(), new StringInterner.FileKey( new_unlinked_file )).getFile();
 
 			try{
 
@@ -361,7 +373,7 @@ FMFileImpl
 				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "getCanonicalPath fails", e ));
 			}
 
-			if ( new_linked_file.exists()){
+			if ( FileUtil.exists( new_linked_file )){
 
 				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "moveFile fails - file '" + new_canonical_path + "' already exists"));
 			}
@@ -372,10 +384,12 @@ FMFileImpl
 
 			createDirs( new_linked_file );
 
-			if ( !linked_file.exists() || FileUtil.renameFile( linked_file, new_linked_file, pl )) {
+			File lf = linked_file.getFile();
+			
+			if ( !FileUtil.exists( lf ) || FileUtil.renameFile( lf, new_linked_file, pl )) {
 
-				linked_file		= new_linked_file;
-				canonical_path	= new_canonical_path;
+				linked_file		= new StringInterner.FileKey( new_linked_file );
+				canonical_path	= new StringInterner.FileKey( new_canonical_path );
 
 				reserveFile();
 
@@ -421,15 +435,17 @@ FMFileImpl
 		String		new_name )
 
 		throws FMFileManagerException
-	{
+	{		
 		try{
 			this_mon.enter();
 
+			File lf = linked_file.getFile();
+
 			length_cache = getLength();
 			
 			String	new_canonical_path;
 
-			File 	new_linked_file = FileUtil.newFile( linked_file.getParentFile(), new_name );
+			File 	new_linked_file = FileUtil.newFile( lf.getParentFile(), new_name );
 
 			try{
 
@@ -457,19 +473,23 @@ FMFileImpl
 				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "getCanonicalPath fails", e ));
 			}
 
-			if ( new_linked_file.exists()){
-
-				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "renameFile fails - file '" + new_canonical_path + "' already exists"));
+			if ( FileUtil.exists( new_linked_file )){				
+				
+				throw( 
+					new FMFileManagerException( 
+						FMFileManagerException.OP_OTHER, 
+						"renameFile fails - new file '" + new_canonical_path + "' already exists (old file='" +
+								lf + "', exists=" + FileUtil.exists(lf) +")"));
 			}
 
 			boolean	was_open	= isOpen();
 
 			close();	// full close, this will release any slots in the limited file case
 
-			if ( !linked_file.exists() || linked_file.renameTo( new_linked_file )){
+			if ( !FileUtil.exists( lf ) || lf.renameTo( new_linked_file )){
 
-				linked_file		= new_linked_file;
-				canonical_path	= new_canonical_path;
+				linked_file		= new StringInterner.FileKey( new_linked_file );
+				canonical_path	= new StringInterner.FileKey( new_canonical_path );
 
 				reserveFile();
 
@@ -591,9 +611,11 @@ FMFileImpl
 	getFileAccessor()
 		throws FileNotFoundException
 	{
+		File lf = linked_file.getFile();
+		
 		try{
 		
-			fa = FileUtil.newFileAccessor( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
+			fa = FileUtil.newFileAccessor( lf, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
 			
 		}catch( FileNotFoundException e ){
 			
@@ -601,10 +623,14 @@ FMFileImpl
 			
 			if ( 	switch_to_upload_only_enable && 
 					access_mode == FM_WRITE && 
-					linked_file.exists()  && 
-					linked_file.canRead()){
+					FileUtil.exists( lf )  && 
+					lf.canRead()){
 				
-				fa = FileUtil.newFileAccessor( linked_file, READ_ACCESS_MODE );
+				fa = FileUtil.newFileAccessor( lf, READ_ACCESS_MODE );
+				
+			}else{
+				
+				throw( e );
 			}
 		}
 	}
@@ -674,9 +700,11 @@ FMFileImpl
 				// yet allocated - attempt to create the file on demand
 
 			try{
-				linked_file.getParentFile().mkdirs();
+				File lf = linked_file.getFile();
+				
+				lf.getParentFile().mkdirs();
 
-				linked_file.createNewFile();
+				lf.createNewFile();
 
 				getFileAccessor();
 
@@ -693,13 +721,13 @@ FMFileImpl
 
 				Debug.printStackTrace( e );
 
-				throw( new FMFileManagerException( access_mode==FM_READ?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "open fails for '" + linked_file.getAbsolutePath() + "'", e ));
+				throw( new FMFileManagerException( access_mode==FM_READ?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "open fails for '" + linked_file.getFile().getAbsolutePath() + "'", e ));
 			}
 		}catch( Throwable e ){
 
 			Debug.printStackTrace( e );
 
-			throw( new FMFileManagerException( access_mode==FM_READ?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "open fails for '" + linked_file.getAbsolutePath() + "'", e ));
+			throw( new FMFileManagerException( access_mode==FM_READ?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "open fails for '" + linked_file.getFile().getAbsolutePath() + "'", e ));
 		}
 	}
 
@@ -791,9 +819,11 @@ FMFileImpl
 	{
 		close();
 
-		if ( linked_file.exists()){
+		File lf = linked_file.getFile();
 
-			if ( !linked_file.delete()){
+		if ( FileUtil.exists( lf )){
+
+			if ( !lf.delete()){
 
 				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "Failed to delete '" + linked_file + "'" ));
 			}
@@ -890,7 +920,7 @@ FMFileImpl
 	getLastModified()
 	{
 		if (last_modified == 0) {
-			last_modified = linked_file.lastModified();
+			last_modified = linked_file.getFile().lastModified();
 		}
 		return( last_modified );
 	}
@@ -1001,9 +1031,11 @@ FMFileImpl
 
 			if ( owners == null ){
 
-				Debug.out( "reserveAccess fail" );
+				String str = "File '"+canonical_path+"' has not been reserved (no entries), '" + owner.getName()+"'";
+						
+				Debug.out( "reserveAccess fail: " + str );
 
-				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "File '"+canonical_path+"' has not been reserved (no entries), '" + owner.getName()+"'"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, str ));
 			}
 
 			for ( Object[] entry: owners ){
@@ -1020,9 +1052,11 @@ FMFileImpl
 
 			if ( my_entry == null ){
 
-				Debug.out( "reserveAccess fail" );
+				String str = "File '"+canonical_path+"' has not been reserved (not found), '" + owner.getName()+"'";
+				
+				Debug.out( "reserveAccess fail: " + str );
 
-				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "File '"+canonical_path+"' has not been reserved (not found), '" + owner.getName()+"'"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, str ));
 			}
 
 			my_entry[1] = Boolean.valueOf(access_mode == FM_WRITE);
@@ -1197,13 +1231,13 @@ FMFileImpl
 
 		File	parent = target.getParentFile();
 
-		if ( !parent.exists()){
+		if ( !FileUtil.existsWithCache( parent )){
 
 			List<File>	new_dirs = new ArrayList<>();
 
 			File	current = parent;
 
-			while( current != null && !current.exists()){
+			while( current != null && !FileUtil.exists( current )){
 
 				new_dirs.add( current );
 
@@ -1263,7 +1297,7 @@ FMFileImpl
 
 				// delete any dirs we created if the target file doesn't exist
 
-			if ( !created_dirs_leaf.exists()){
+			if ( !FileUtil.exists( created_dirs_leaf )){
 
 				Iterator<File>	it = created_dirs.iterator();
 
@@ -1271,7 +1305,7 @@ FMFileImpl
 
 					File	dir = it.next();
 
-					if ( dir.exists() && dir.isDirectory()){
+					if ( FileUtil.exists( dir ) && dir.isDirectory()){
 
 						File[]	entries = dir.listFiles();
 
@@ -1300,7 +1334,9 @@ FMFileImpl
 	protected String
 	getString()
 	{
-		File cPath = FileUtil.newFile(canonical_path);
+		String cp = canonical_path.toString();
+		
+		File cPath = canonical_path.getFile();
 		String sPaths;
 		
 		FileAccessor current_fa = fa;
@@ -1309,11 +1345,11 @@ FMFileImpl
 		
 		if (cPath.equals(linked_file)){
 			
-			sPaths = "can/link=" + Debug.secretFileName(canonical_path);
+			sPaths = "can/link=" + Debug.secretFileName(cp);
 			
 		}else{
 			
-			sPaths = "can=" + Debug.secretFileName(canonical_path) + ",link="
+			sPaths = "can=" + Debug.secretFileName(cp) + ",link="
 					+ Debug.secretFileName(linked_file.toString());
 		}
 		
@@ -1333,11 +1369,11 @@ FMFileImpl
 			try{
 				file_map_mon.enter();
 
-				Iterator<String>	it = file_map.keySet().iterator();
+				Iterator<StringInterner.FileKey>	it = file_map.keySet().iterator();
 
 				while( it.hasNext()){
 
-					String	key = (String)it.next();
+					StringInterner.FileKey	key = it.next();
 
 					List<Object[]>	owners = file_map.get(key);
 
@@ -1358,7 +1394,7 @@ FMFileImpl
 					}
 
 
-					writer.println( Debug.secretFileName(key) + " -> " + str );
+					writer.println( Debug.secretFileName(key.toString()) + " -> " + str );
 				}
 			}finally{
 
