@@ -101,7 +101,8 @@ DiskManagerFileInfoFile
 	@Override
 	public void
 	setLink(
-		File	link_destination )
+		File	link_destination,
+		boolean	no_delete )
 	{
 		throw( new RuntimeException( "Not supported" ));
 	}
