@@ -922,15 +922,6 @@ DownloadManager
     	int		event_type,
     	Object	event_data );
 
-		/**
-		 * Sets the priority for an array for files
-		 *
-		 * @param fileInfos
-		 * @param type
-		 * @since 5.6.2.1
-		 */
-	public void setFilePriorities(DiskManagerFileInfo[] fileInfos, int type);
-
 	public void
 	requestAttention();
 }
\ No newline at end of file
