@@ -58,6 +58,7 @@ import com.biglybt.core.tracker.client.TRTrackerAnnouncer;
 import com.biglybt.core.tracker.client.TRTrackerAnnouncerDataProvider;
 import com.biglybt.core.tracker.client.TRTrackerScraperResponse;
 import com.biglybt.core.util.*;
+import com.biglybt.core.util.StringInterner.FileKey;
 import com.biglybt.core.util.bloom.BloomFilter;
 import com.biglybt.core.util.bloom.BloomFilterFactory;
 import com.biglybt.pif.PluginInterface;
@@ -187,7 +188,8 @@ DownloadManagerController
 	private DiskManagerListener				disk_manager_listener_use_accessors;
 
 	private Object							disk_manager_pieces_snapshot_lock = new Object();
-	private volatile DiskManagerPiece[]		disk_manager_pieces_snapshot;
+	
+	private volatile WeakReference<DiskManagerPiece[]>		disk_manager_pieces_snapshot;
 	
 	final FileInfoFacadeSet		fileFacadeSet = new FileInfoFacadeSet();
 	boolean					files_facade_destroyed;
@@ -512,7 +514,17 @@ DownloadManagerController
 					public int
 					getMaxNewConnectionsAllowed( String network )
 					{
-						return( temp.getMaxNewConnectionsAllowed( network ));
+						int num = temp.getMaxNewConnectionsAllowed( network );
+						
+							// if we have a download with 0 peers and we're at the connection limit then ask for a few to try and get it started
+							// if by the time we connect to a peer we are still at the limit the then connection will be declined anyway
+						
+						if ( num < 5 && getConnectedConnectionCount() == 0 && getPendingConnectionCount() < 5 ){
+							
+							num = 5;
+						}
+						
+						return( num );
 					}
 
 					@Override
@@ -1412,7 +1424,7 @@ DownloadManagerController
 
 	  					File	save_dir_file	= download_manager.getAbsoluteSaveLocation();
 
-	  					if ( save_dir_file != null && save_dir_file.exists() && save_dir_file.isDirectory()){
+	  					if ( save_dir_file != null && FileUtil.exists( save_dir_file ) && save_dir_file.isDirectory()){
 
 	  						TorrentUtils.recursiveEmptyDirDelete( save_dir_file, false );
 	  					}
@@ -1431,7 +1443,7 @@ DownloadManagerController
 
   		if ( call_filesExist ){
 
-  			filesExist( true );
+  			filesExist( true, false );
   		}
 
   		if ( _inform_changed ){
@@ -2168,7 +2180,8 @@ DownloadManagerController
 
 	public boolean
 	filesExist(
-		boolean	expected_to_be_allocated )
+		boolean	expected_to_be_allocated, 
+		boolean	test_only )
 	{
 		if ( !expected_to_be_allocated ){
 
@@ -2181,7 +2194,7 @@ DownloadManagerController
 		DiskManager dm = getDiskManager();
 
 		if (dm != null) {
-			return dm.filesExist();
+			return( dm.filesExist());
 		}
 
 		fileFacadeSet.makeSureFilesFacadeFilled(false);
@@ -2204,30 +2217,67 @@ DownloadManagerController
 
 					boolean 	exists = fileInfo.exists();
 
-					File file = fileInfo.getFile(true);
+					File data_file = fileInfo.getFile(true);
 
 					long elapsed = SystemTime.getMonotonousTime() - start;
 
 					if ( elapsed >= 500 ){
 
-						Debug.out( "Accessing '" + file.getAbsolutePath() + "' in '" + getDisplayName() + "' took " + elapsed + "ms - possibly offline" );
+						Debug.out( "Accessing '" + data_file.getAbsolutePath() + "' in '" + getDisplayName() + "' took " + elapsed + "ms - possibly offline" );
 					}
 
+					if ( !exists && !test_only ){
+						
+						String incomplete_suffix = download_manager_state.getAttribute( DownloadManagerState.AT_INCOMP_FILE_SUFFIX );
+
+		               	String name = data_file.getName();
+
+						if ( incomplete_suffix != null ){
+	                	
+							if ( name.endsWith( incomplete_suffix )){
+								
+			                	File test_file = FileUtil.newFile( data_file.getParentFile(), name.substring( 0, name.length() - incomplete_suffix.length()));
+			                	
+			                	if ( FileUtil.exists( test_file )){
+			                			
+			                		FileUtil.log( "Moving '" + test_file + "' to '" + data_file + "' to restore the incomplete file suffix" );
+			                		
+				                	FileUtil.renameFile( test_file, data_file );
+			                	}
+							}else{
+           	
+								File test_file = FileUtil.newFile( data_file.getParentFile(), name + incomplete_suffix );
+			                	
+			                	if ( FileUtil.exists( test_file )){
+			                			
+			                		FileUtil.log( "Moving '" + test_file + "' to '" + data_file + "' to remove the incomplete file suffix" );
+			                		
+				                	FileUtil.renameFile( test_file, data_file );
+			                	}
+							}
+							
+							exists = fileInfo.exists();
+						}
+					}
+					
 					if ( !exists ){
 
 						// For multi-file torrents, complain if the save directory is missing.
 						if (!this.download_manager.getTorrent().isSimpleTorrent()) {
 							File save_path = this.download_manager.getAbsoluteSaveLocation();
-							if (FileUtil.isAncestorOf(save_path, file) && !save_path.exists()) {
-								file = save_path; // We're going to abort very soon, so it's OK to overwrite this.
+							if (FileUtil.isAncestorOf(save_path, data_file) && !FileUtil.exists(save_path )) {
+								data_file = save_path; // We're going to abort very soon, so it's OK to overwrite this.
 							}
 						}
 
-						setFailed( DownloadManager.ET_FILE_MISSING, MessageText.getString("DownloadManager.error.datamissing") + ": " + file.getAbsolutePath());
+						if ( !test_only ){
+						
+							setFailed( DownloadManager.ET_FILE_MISSING, MessageText.getString("DownloadManager.error.datamissing") + ": " + data_file.getAbsolutePath());
+						}
 						
 						return false;
 
-					} else if (fileInfo.getLength() < file.length()) {
+					} else if (fileInfo.getLength() < data_file.length()) {
 
 							// file may be incremental creation - don't complain if too small
 
@@ -2235,16 +2285,21 @@ DownloadManagerController
 
 						if ( !COConfigurationManager.getBooleanParameter("File.truncate.if.too.large")){
 
-							setFailed(MessageText.getString("DownloadManager.error.badsize")
-									+ " " + file + "(" + fileInfo.getLength() + "/" + file.length() + ")");
-
+							if ( !test_only ){
+							
+								setFailed(MessageText.getString("DownloadManager.error.badsize")
+									+ " " + data_file + "(" + fileInfo.getLength() + "/" + data_file.length() + ")");
+							}
 
 							return false;
 						}
 					}
 				}catch( Throwable e ){
 					
-					setFailed( "Existance check failed", e );
+					if ( !test_only ){
+					
+						setFailed( "Existance check failed", e );
+					}
 					
 					return false;
 				}
@@ -2395,12 +2450,15 @@ DownloadManagerController
 	{
 		synchronized( disk_manager_pieces_snapshot_lock ){
 		
-			if ( disk_manager_pieces_snapshot == null ){
+			WeakReference<DiskManagerPiece[]> snap = disk_manager_pieces_snapshot;
+			
+			if ( snap == null || snap.get() == null ){
 				
-				disk_manager_pieces_snapshot = DiskManagerUtil.getDiskManagerPiecesSnapshot( download_manager );			
+				disk_manager_pieces_snapshot = snap = 
+					new WeakReference<>( DiskManagerUtil.getDiskManagerPiecesSnapshot( download_manager, getDiskManagerFileInfoSet()));			
 			}
 			
-			return( disk_manager_pieces_snapshot );
+			return( snap.get() );
 		}
 	}
 
@@ -2557,6 +2615,18 @@ DownloadManagerController
 	{
 		stats.setDownloadRateLimitBytesPerSecond( b );
 	}
+	
+	protected void
+	rateLimitChanged()
+	{
+		DiskManager dm = getDiskManager();
+		
+		if ( dm != null ){
+			
+			dm.rateLimitChanged();
+		}
+	}
+	
 
 		// these per-download rates are not easy to implement as we either have per-peer limits or global limits, with the download-limits being implemented
 		// by adding them to all peers as peer-limits. So for the moment we stick with global (non-lan) limits
@@ -3591,7 +3661,7 @@ DownloadManagerController
 				writer.println("Force Start");
 			}
 
-			writer.println("FilesExist? " + filesExist(download_manager.isDataAlreadyAllocated()));
+			writer.println("FilesExist? " + filesExist(download_manager.isDataAlreadyAllocated(), true));
 			
 			if ( full ){
 				
@@ -3606,7 +3676,29 @@ DownloadManagerController
 						
 						File f = file.getFile( true );
 								
-						writer.println( file.getIndex() + ": " + f + ", exists=" + f.exists());
+						writer.println( file.getIndex() + ": " + f + ", exists=" + FileUtil.exists( f ));
+					}
+				}finally{
+					
+					writer.exdent();
+				}
+				
+				writer.println( "Links" );
+				
+				try{
+					writer.indent();
+					
+					LinkFileMap links = download_manager_state.getFileLinks();
+					
+					Iterator<LinkFileMap.Entry> it = links.entryIterator();
+						
+					while( it.hasNext()){
+						
+						LinkFileMap.Entry entry = it.next();
+														
+						FileKey from = entry.getFromFileMaybeNull();
+						
+						writer.println( entry.getIndex() + ": " + (from==null?"":(from.get()+" ")) + "-> " + entry.getToFile().get());
 					}
 				}finally{
 					
@@ -3836,9 +3928,9 @@ DownloadManagerController
 
 						if ( completed < 1000 ){
 
-							if ( open_for_seeding ){
+							if ( open_for_seeding && stats.getRemainingExcludingDND() > 0 ){
 
-								setFailed( "File check failed" );
+								setFailed( "File check failed for seeding, download is incomplete" );
 
 								download_manager_state.clearResumeData();
 
