@@ -30,10 +30,10 @@ import com.biglybt.core.disk.DiskManagerFileInfo;
 import com.biglybt.core.download.DownloadManager;
 import com.biglybt.core.download.DownloadManagerState;
 import com.biglybt.core.download.DownloadManagerStateAttributeListener;
-import com.biglybt.core.download.DownloadManagerState.ResumeHistory;
 import com.biglybt.core.torrent.TOTorrent;
 import com.biglybt.core.util.IndentWriter;
 import com.biglybt.core.util.LinkFileMap;
+import com.biglybt.core.util.StringInterner.FileKey;
 
 public class
 LWSDiskManagerState
@@ -68,7 +68,7 @@ LWSDiskManagerState
 
 	@Override
 	public File
-	getStateFile()
+	getStateDir()
 	{
 		return null;
 	}
@@ -378,13 +378,6 @@ LWSDiskManagerState
 	{
 	}
 
-	@Override
-	public void
-	setPrimaryFile(
-		DiskManagerFileInfo dmfi)
-	{
-	}
-
 	@Override
 	public DiskManagerFileInfo
 	getPrimaryFile()
@@ -392,6 +385,13 @@ LWSDiskManagerState
 		return null;
 	}
 
+	@Override
+	public String 
+	getPrimaryFilePath()
+	{
+		return null;
+	}
+	
 	@Override
 	public String[]
 	getNetworks()
@@ -484,7 +484,7 @@ LWSDiskManagerState
     public void
 	setFileLinks(
 		List<Integer>	source_indexes,
-		List<File>		link_sources,
+		List<File>		link_sources_may_have_nulls,
 		List<File>		link_destinations )
     {
     }
@@ -514,17 +514,25 @@ LWSDiskManagerState
 	@Override
 	public File
 	getFileLink(
-		int		source_index,
-		File	link_source )
+		int		source_index )
 	{
 		return( null );
 	}
 
+	@Override
+	public FileKey
+	getFileLink(
+		int			source_index,
+		FileKey		def )
+	{
+		return( def );
+	}
+	
 	@Override
 	public LinkFileMap
 	getFileLinks()
 	{
-		return( new LinkFileMap());
+		return( new LinkFileMap( null ));
 	}
 
 	@Override
@@ -610,7 +618,7 @@ LWSDiskManagerState
 	@Override
 	public void
 	generateEvidence(
-		IndentWriter writer)
+		IndentWriter writer, boolean full )
 	{
 	}
 
