@@ -40,6 +40,7 @@ import com.biglybt.core.networkmanager.admin.NetworkAdminASN;
 import com.biglybt.core.networkmanager.admin.NetworkAdminASNListener;
 import com.biglybt.core.networkmanager.admin.NetworkAdminException;
 import com.biglybt.core.peer.PEPeer;
+import com.biglybt.core.peermanager.peerdb.PeerItemFactory;
 import com.biglybt.core.util.*;
 import com.biglybt.pif.peers.Peer;
 import com.biglybt.pif.utils.LocationProvider;
@@ -126,6 +127,12 @@ public class PeerUtils {
 			});
    }
 
+   public static void
+   initialise()
+   {
+	   PeerItemFactory.initialise();
+   }
+   
    public static int
    getPeerPriority(
 	   String 	address,
@@ -355,7 +362,7 @@ public class PeerUtils {
 	 int 					specific_max )
   {
 	 // max will have been adjusted based on network selection so we don't actually need to use
-	 // nework info any further during this calculation
+	 // network info any further during this calculation
 
     int curConnPerTorrent = PeerIdentityManager.getIdentityCount( data_id );
 
@@ -546,6 +553,10 @@ public class PeerUtils {
 
 		return( country_provider );
 	}
+	
+	public static boolean hasCountryProvider() {
+		return getCountryProvider() != null;
+	}
 
 	public static String[]
  	getCountryDetails(
