@@ -1280,9 +1280,9 @@ TagManagerImpl
 													}
 
 													@Override
-													public void
-													run(
-															CoreOperation operation)
+													public boolean
+													runOperation(
+														CoreOperation operation)
 													{
 														try{
 															manager.copyDataFiles( new_loc, cb );
@@ -1291,6 +1291,8 @@ TagManagerImpl
 
 															throw( new RuntimeException( e ));
 														}
+														
+														return( true );
 													}
 
 													@Override
@@ -2617,7 +2619,7 @@ TagManagerImpl
 			return;
 		}
 
-		if ( tag.isRemoved() && type != CU_TAG_REMOVE ){
+		if ( tag.isTagRemoved() && type != CU_TAG_REMOVE ){
 
 			return;
 		}
@@ -2641,7 +2643,7 @@ TagManagerImpl
 			int				type	= (Integer)update[0];
 			TagWithState	tag 	= (TagWithState)update[1];
 
-			if ( tag.isRemoved()){
+			if ( tag.isTagRemoved()){
 
 				type = CU_TAG_REMOVE;
 			}
