@@ -250,6 +250,7 @@ AEThread2
 		AEThread.setOurThread( thread );
 	}
 
+	/*
 	public static void
 	setDebug(
 		Object		debug )
@@ -261,13 +262,13 @@ AEThread2
 			((threadWrapper)current).setDebug( debug );
 		}
 	}
-
+	*/
 		/**
 		 * entry 0 is debug object, 1 is Long mono-time it was set
 		 * @param t
 		 * @return
 		 */
-
+	/*
 	public static Object[]
 	getDebug(
 		Thread		t )
@@ -279,7 +280,8 @@ AEThread2
 
 		return( null );
 	}
-
+	*/
+	
 	protected static class
 	threadWrapper
 		extends Thread
@@ -290,7 +292,7 @@ AEThread2
 
 		private long		last_active_time;
 
-		private Object[]		debug;
+		//private Object[]		debug;
 
 		protected
 		threadWrapper(
@@ -342,7 +344,7 @@ AEThread2
 
 						target = PENDING;
 
-						debug	= null;
+						// debug	= null;
 
 						currentLock.released = true;
 
@@ -457,6 +459,7 @@ AEThread2
 			LockSupport.unpark( this );
 		}
 
+		/*
 		protected void
 		setDebug(
 			Object	d )
@@ -469,6 +472,7 @@ AEThread2
 		{
 			return( debug );
 		}
+		*/
 	}
 
 	public void
