@@ -4,16 +4,17 @@ import java.lang.reflect.*;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.Arrays;
+import java.util.List;
 
 import com.biglybt.core.Core;
 import com.biglybt.core.CoreFactory;
 import com.biglybt.core.config.COConfigurationListener;
 import com.biglybt.core.config.COConfigurationManager;
-import com.biglybt.core.config.ConfigKeys;
 import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.networkmanager.admin.NetworkAdmin;
 import com.biglybt.core.util.AENetworkClassifier;
 import com.biglybt.core.util.Constants;
+import com.biglybt.core.util.NetUtils;
 import com.biglybt.core.util.TorrentUtils;
 import com.biglybt.pif.PluginAdapter;
 import com.biglybt.pif.PluginInterface;
@@ -115,26 +116,47 @@ AENameServiceJava18
 							throw( new RuntimeException( "Delegate Name Service unavailable" ));
 						}
 	
-						host_name = COConfigurationManager.getStringParameter(
-							ConfigKeys.Connection.SCFG_CONNECTION_TEST_DOMAIN);
+						List<String> domains = NetUtils.getTestDomains();
+
+						if ( domains.isEmpty()){
+							
+							throw( new RuntimeException( "No test domains available" ));
+						}
+						
+						RuntimeException 	last_error	= null;
+						boolean				maybe_ok	= false;
+						
+						for ( String domain: domains ){
 	
-						try{
-							Object result = delegate_method.invoke( delegate, host_name, args[1] );
-	
-						}catch( Throwable e ){
-	
-							if ( e instanceof UnknownHostException ){
-	
-								// guess their DNS might be down - don't treat as complete fail
-	
-								System.err.println( "DNS resolution of " + host_name + " failed, DNS unavailable?" );
-	
-							}else{
-	
-								throw( new RuntimeException( "Delegate lookup failed", e ));
+							try{
+								Object result = delegate_method.invoke( delegate, domain, args[1] );
+		
+								last_error = null;
+								
+								break;
+								
+							}catch( Throwable e ){
+		
+								if ( e instanceof UnknownHostException ){
+		
+									// guess their DNS might be down - don't treat as complete fail
+		
+									System.err.println( "DNS resolution of " + domain + " failed, DNS unavailable?" );
+		
+									maybe_ok = true;
+									
+								}else{
+		
+									last_error = new RuntimeException( "Delegate lookup failed", e );
+								}
 							}
 						}
 	
+						if ( last_error != null && !maybe_ok ){
+							
+							throw( last_error );
+						}
+	
 						InetAddress[] result = new InetAddress[]{ InetAddress.getByAddress( new byte[]{ 127, 0, 0, 1 })};
 						
 						return( Arrays.stream( result ));
