@@ -251,7 +251,8 @@ RPDiskManagerFileInfo
 	@Override
 	public void
 	setLink(
-		File	link_destination )
+		File	link_destination,
+		boolean	dont_delete )
 	{
 		notSupported();
 	}
