@@ -729,7 +729,7 @@ MagnetPlugin
 
 					}catch( DownloadException e ){
 
-						throw( new MagnetURIHandlerException( "Operation failed", e ));
+						throw( new MagnetURIHandlerException( "Operation failed", false, e ));
 					}
 				}
 
@@ -1127,7 +1127,10 @@ MagnetPlugin
 										failed(
 											MagnetURIHandlerException error )
 										{
-											Debug.out( error );
+											if ( !error.isManuallyCancelled()){
+											
+												Debug.out( error );
+											}
 										}
 										
 										@Override
@@ -1138,7 +1141,7 @@ MagnetPlugin
 											if ( result != null ){
 												
 												try{
-													TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray( result );
+													TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray( new TOTorrentFactory.TorrentDataHolder( result ));
 													
 													String	torrent_name = FileUtil.convertOSSpecificChars( TorrentUtils.getLocalisedName( torrent ) + ".torrent", false );
 													
@@ -1558,7 +1561,7 @@ MagnetPlugin
 		}catch( Throwable e ) {
 			
 			try{
-				_dl_listener.failed( new MagnetURIHandlerException( "Magnet download failed", e ));
+				_dl_listener.failed( new MagnetURIHandlerException( "Magnet download failed", false, e ));
 				
 			}finally{
 			
@@ -1834,7 +1837,7 @@ MagnetPlugin
 		if ( dn != null || new_web_seeds.size() > 0 || new_trackers.size() > 0 || networks.size() > 0 || !initial_tags.isEmpty() || !other_metadata.isEmpty()){
 
 			try{
-				TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray( torrent_data );
+				TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray(new TOTorrentFactory.TorrentDataHolder( torrent_data ));
 
 				boolean	update_torrent = false;
 
@@ -2223,7 +2226,7 @@ MagnetPlugin
 
 				}else{
 
-					error = new MagnetURIHandlerException( "Download failed", _error );
+					error = new MagnetURIHandlerException( "Download failed", false, _error );
 				}
 				
 				to_do = listeners;
@@ -2480,9 +2483,13 @@ MagnetPlugin
 
 										if ( dummy_hash || Arrays.equals( torrent.getHash(), hash )){
 
+											Map map = torrent.serialiseToMap();
+											
+											torrent = null;
+											
 											synchronized( md_downloader ){
 
-												result_holder[0] = BEncoder.encode( torrent.serialiseToMap());
+												result_holder[0] = BEncoder.encode( map );
 											}
 										}
 									}
@@ -2522,6 +2529,8 @@ MagnetPlugin
 								
 								result_listener.complete( new DownloadResult( result_holder[0], networks_enabled, additional_networks,  md_downloader[0] ));
 								
+								result_holder[0] = null;
+								
 								return;
 							}
 						}
@@ -2616,7 +2625,7 @@ MagnetPlugin
 									@Override
 									public void
 									complete(
-										TOTorrent		torrent,
+										TOTorrent[]		torrent,
 										Set<String>		peer_networks )
 									{
 										if ( listener != null ){
@@ -2628,7 +2637,11 @@ MagnetPlugin
 											additional_networks.addAll( peer_networks );
 
 											try{
-												result_holder[0] = BEncoder.encode( torrent.serialiseToMap());
+												Map map = torrent[0].serialiseToMap();
+											
+												torrent[0] = null;
+											
+												result_holder[0] = BEncoder.encode(  map );
 
 											}catch( Throwable e ){
 
@@ -2701,6 +2714,8 @@ MagnetPlugin
 
 								result_listener.complete( new DownloadResult( result_holder[0], networks_enabled, additional_networks, md_downloader[0] ));
 								
+								result_holder[0] = null;
+								
 								return;
 							}
 							
@@ -2952,6 +2967,8 @@ MagnetPlugin
 										
 										result_listener.complete( new DownloadResult( result_holder[0], networks_enabled, additional_networks, md_downloader[0] ));
 										
+										result_holder[0] = null;
+										
 										return;
 									}
 									
@@ -3074,7 +3091,7 @@ MagnetPlugin
 													byte[]	data = (byte[])value.getValue(byte[].class);
 
 													try{
-														TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray( data );
+														TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray( new TOTorrentFactory.TorrentDataHolder( data ));
 
 														if ( Arrays.equals( hash, torrent.getHash())){
 
@@ -3131,6 +3148,8 @@ MagnetPlugin
 
 										result_listener.complete( new DownloadResult( result_holder[0], networks_enabled, additional_networks, md_downloader[0] ));
 										
+										result_holder[0] = null;
+										
 										return;
 									}
 									
@@ -3201,12 +3220,16 @@ MagnetPlugin
 														done = true;
 														
 														result_listener.complete( new DownloadResult( result_holder[0], networks_enabled, additional_networks, md_downloader[0] ));
-																												
+																
+														result_holder[0] = null;
+														
 													}else if ( result_error[0] != null ){
 						
 														done = true;
 														
-														result_listener.failed( new MagnetURIHandlerException( "MagnetURIHandler failed", result_error[0] ));
+														boolean mc = manually_cancelled[0];
+														
+														result_listener.failed( new MagnetURIHandlerException( "MagnetURIHandler failed", mc, result_error[0] ));
 													}
 												}
 												
@@ -3259,13 +3282,19 @@ MagnetPlugin
 
 			}catch( Throwable e ){
 
-				Debug.printStackTrace(e);
-
+				synchronized( md_downloader ){
+					
+					if ( !manually_cancelled[0]){
+						
+						Debug.printStackTrace(e);
+					}
+				}
+				
 				if ( listener != null ){
 					listener.reportActivity( getMessageText( "report.error", Debug.getNestedExceptionMessage(e)));
 				}
 
-				result_listener.failed( new MagnetURIHandlerException( "MagnetURIHandler failed", e ));
+				result_listener.failed( new MagnetURIHandlerException( "MagnetURIHandler failed", false, e ));
 				
 				return;
 			}
