@@ -21,6 +21,8 @@
 package com.biglybt.plugin.net.buddy;
 
 import java.io.File;
+import java.io.PrintWriter;
+import java.io.StringWriter;
 import java.net.Inet4Address;
 import java.net.Inet6Address;
 import java.net.InetAddress;
@@ -45,6 +47,7 @@ import com.biglybt.pif.utils.PooledByteBuffer;
 import com.biglybt.pif.utils.security.SEPublicKey;
 import com.biglybt.pif.utils.security.SEPublicKeyLocator;
 import com.biglybt.plugin.net.buddy.BuddyPluginNetwork.DDBDetails;
+import com.biglybt.plugin.net.buddy.tracker.BuddyPluginTracker;
 
 
 public class
@@ -877,7 +880,29 @@ BuddyPluginBuddy
 		return( result );
 	}
 
-
+	public String
+	getProperties()
+	{
+		StringWriter sw = new StringWriter( 1024 );
+		
+		IndentWriter writer = new IndentWriter( new PrintWriter( sw ));
+		
+		writer.println( "current ip: " + AddressUtils.getHostAddress( current_ip ));
+		writer.println( "latest ipv4: " + AddressUtils.getHostAddress( latest_ipv4 ));
+		writer.println( "latest ipv6: " + AddressUtils.getHostAddress( latest_ipv6 ));
+		writer.println( "ports: " + tcp_port + "/" + udp_port );
+		writer.println( "online: " + online );
+		writer.println( "connected: " + isConnected());
+		
+		BuddyPluginTracker tracker = plugin_network.getPlugin().getTracker();
+		
+		tracker.getProperties( this, writer );
+		
+		writer.close();
+		
+		return( sw.toString());
+	}
+	
 	public int
 	getTCPPort()
 	{
