@@ -788,18 +788,7 @@ ShareHosterPlugin
 			try{
 				download_being_removed	= dl;
 
-					// the resource has gone! stop torrent if running to permit
-					// deletion
-
-				try{
-					dl.stop();
-
-				}catch( Throwable e ){
-
-					// ignore this as it might already be stopped
-				}
-
-				dl.remove();
+				dl.stopAndRemove(false, false);
 
 			}catch( Throwable e ){
 
@@ -849,4 +838,4 @@ ShareHosterPlugin
 	{
 		log.log( LoggerChannel.LT_INFORMATION, "Current Task:".concat(task_description) );
 	}
-}
\ No newline at end of file
+}
