@@ -906,7 +906,7 @@ WebPlugin
 					parameterChanged(
 						Parameter param )
 					{
-						updatePairing( p_sid );
+						updatePairing( p_sid, "Parameter '" + param.getLabelText() + "' changed" );
 
 						setupUPnP();
 					}
@@ -1206,9 +1206,10 @@ WebPlugin
 
 		if ( !file_root.exists()){
 
-			String	error = "WebPlugin: root dir '" + file_root + "' doesn't exist";
-
-			log.log( LoggerChannel.LT_ERROR, error );
+			// assume resource coming from jar, not an error
+			
+			// String	error = "WebPlugin: root dir '" + file_root + "' doesn't exist";
+			// log.log( LoggerChannel.LT_ERROR, error );
 
 		}else if ( !file_root.isDirectory()){
 
@@ -1488,7 +1489,7 @@ WebPlugin
 
 									if ( p_sid != null ){
 
-										updatePairing( p_sid );
+										updatePairing( p_sid, "I2P destination" );
 									}
 								}
 							}
@@ -1537,7 +1538,7 @@ WebPlugin
 
 									if ( p_sid != null ){
 
-										updatePairing( p_sid );
+										updatePairing( p_sid, "Tor destination" );
 									}
 								}
 							}
@@ -1696,6 +1697,8 @@ WebPlugin
 					{
 						boolean	result;
 
+						String error = null;
+
 						boolean	auto_auth =  param_auto_auth != null && param_auto_auth.getValue();
 
 						if ( !pw_enable.getValue()){
@@ -1747,7 +1750,7 @@ WebPlugin
 								}
 																
 								result = false;
-								
+																
 								String msg	= "";
 								
 								boolean port_ok = false;
@@ -1903,7 +1906,7 @@ WebPlugin
 								if ( !result ){
 									
 									
-									log.log( "Access denied: No password and " + msg + " (" + client_address + ")");
+									error = "Access denied: No password and " + msg + " (" + client_address + ")";
 								}
 							}
 						}else{
@@ -1917,7 +1920,7 @@ WebPlugin
 
 							if ( !user.equals( p_user_name.getValue())){
 
-								log.log( "Access denied: Incorrect user name: " + user + " (" + client_address + ")" );
+								error = "Access denied: Incorrect user name: " + user + " (" + client_address + ")";
 								
 								result = false;
 
@@ -1938,7 +1941,7 @@ WebPlugin
 								
 								if ( !result ){
 									
-									log.log( "Access denied: Incorrect password" + " (" + client_address + ")" );
+									error = "Access denied: Incorrect password" + " (" + client_address + ")";
 								}
 							}
 						}
@@ -1968,6 +1971,16 @@ WebPlugin
 							result = hasOurCookie( getHeaderField( headers, "Cookie" ));
 						}
 
+						if ( !result ){
+							
+							if ( error == null ){
+								
+								error = "Access denied";
+							}
+							
+							log.log( error );
+						}
+						
 						return( result );
 					}
 
@@ -2309,7 +2322,8 @@ WebPlugin
 
 	protected void
 	updatePairing(
-		String		sid )
+		String		sid,
+		String		reason )
 	{
 		PairingManager pm = PairingManagerFactory.getSingleton();
 
@@ -2319,7 +2333,7 @@ WebPlugin
 
 			PairingConnectionData cd = service.getConnectionData();
 
-			log( "Updating pairing information" );
+			log( "Updating pairing information - " + reason );
 
 			try{
 				updatePairing( cd );
