@@ -821,8 +821,8 @@ public class Initializer
 											}
 											
 											@Override
-											public void
-											run(
+											public boolean
+											runOperation(
 												CoreOperation operation)
 											{
 												try{												
@@ -832,6 +832,8 @@ public class Initializer
 		
 													throw( new RuntimeException( e ));
 												}
+												
+												return( true );
 											}
 		
 											@Override
@@ -1032,7 +1034,7 @@ public class Initializer
 			clientMsgContext.setMessageDispatcher(new MessageDispatcherSWT(clientMsgContext));
 			clientMsgContext.addMessageListener(new TorrentListener());
 			clientMsgContext.addMessageListener(new VuzeListener());
-			clientMsgContext.addMessageListener(new DisplayListener());
+			clientMsgContext.addMessageListener(new DisplayListener(null));
 			clientMsgContext.addMessageListener(new ConfigListener(null));
 		}
 	}
