@@ -75,6 +75,7 @@ import com.biglybt.ui.swt.pif.UISWTGraphic;
 import com.biglybt.ui.swt.sharing.ShareUtils;
 import com.biglybt.ui.swt.views.FilesViewMenuUtil;
 import com.biglybt.ui.swt.views.columnsetup.TableColumnSetupWindow;
+import com.biglybt.ui.swt.views.table.TableRowViewer;
 import com.biglybt.ui.swt.views.table.TableSelectedRowsListener;
 import com.biglybt.ui.swt.views.table.TableViewSWT;
 import com.biglybt.ui.common.table.impl.TableContextMenuManager;
@@ -832,7 +833,7 @@ public class TorrentMenuFancy
 
 			pause = pause || ManagerUtils.isPauseable( dm );
 			
-			recheck = recheck || dm.canForceRecheck();
+			recheck = recheck || ManagerUtils.canForceRecheck( dm );
 
 			int state = dm.getState();
 			bChangeDir &= (state == DownloadManager.STATE_ERROR
@@ -924,8 +925,8 @@ public class TorrentMenuFancy
 				"recheck", recheck, new ListenerDMTask(dms) {
 					@Override
 					public void run(DownloadManager dm) {
-						if (dm.canForceRecheck()) {
-							dm.forceRecheck();
+						if (ManagerUtils.canForceRecheck( dm )) {
+							ManagerUtils.forceRecheck( dm );
 						}
 					}
 				});
@@ -1308,7 +1309,7 @@ public class TorrentMenuFancy
 								if ( stopped && !hasClearableLinks ){
 									TOTorrent torrent = dm.getTorrent();
 									if ( torrent != null && !torrent.isSimpleTorrent()){
-										if ( dms.getFileLinks().hasLinks()){
+										if ( dms.getFileLinks().size() > 0){
 											hasClearableLinks = true;
 										}
 									}
@@ -1399,7 +1400,7 @@ public class TorrentMenuFancy
 								public void run(DownloadManager dm)
 								{
 									if ( 	ManagerUtils.isStopped(dm) &&
-											dm.getDownloadState().getFileLinks().hasLinks()){
+											dm.getDownloadState().getFileLinks().size() > 0){
 
 										DiskManagerFileInfoSet fis = dm.getDiskManagerFileInfoSet();
 
@@ -1506,7 +1507,7 @@ public class TorrentMenuFancy
 								
 									for ( DownloadManagerState.ResumeHistory h: history ){
 										MenuItem itemHistory = new MenuItem(restore_menu, SWT.PUSH);
-										itemHistory.setText( new SimpleDateFormat().format( new Date(h.getDate())));
+										itemHistory.setText( DisplayFormatters.formatDateYMDHM(h.getDate()));
 										
 										itemHistory.addListener(SWT.Selection,(ev)->{
 											dmState.restoreResumeData( h );;
@@ -2102,6 +2103,20 @@ public class TorrentMenuFancy
 			});
 		}
 
+			// row details
+		
+		createRow(detailArea, "MyTorrentsView.menu.row.details", null, new Listener() {
+			@Override
+			public void handleEvent(Event event) {
+				TableRowCore focusedRow = tv.getFocusedRow();
+				if (focusedRow == null || focusedRow.isRowDisposed()) {
+					focusedRow = tv.getRow(0);
+				}
+				String tableID = tv.getTableID();
+				new TableRowViewer(tv.getDataSourceType(), tableID,  focusedRow );
+			}
+		});
+		
 		createRow(detailArea, "MyTorrentsView.menu.editTableColumns", "columns", new Listener() {
 			@Override
 			public void handleEvent(Event event) {
@@ -2111,7 +2126,7 @@ public class TorrentMenuFancy
 				}
 				String tableID = tv.getTableID();
 				new TableColumnSetupWindow(tv.getDataSourceType(), tableID, column, focusedRow,
-						TableStructureEventDispatcher.getInstance(tableID)).open();
+						TableStructureEventDispatcher.getInstance(tableID), false );
 			}
 		});
 	}
