@@ -624,7 +624,10 @@ UserAlerts
 							
 							native_tray_icon.setPopupMenu( menu );
 							
-							MenuItem mi = new MenuItem( MessageText.getString( "sharing.progress.hide" ));
+							// Bug with internationalised text - https://github.com/BiglySoftware/BiglyBT/issues/3376
+							// so just use an X which should be pretty obvious to most
+							// MenuItem mi = new MenuItem( MessageText.getString( "sharing.progress.hide" ));
+							MenuItem mi = new MenuItem( "X" );
 							
 							mi.addActionListener(
 								new ActionListener(){
