@@ -19,8 +19,10 @@
 package com.biglybt.ui.swt.components.graphics;
 
 import java.text.SimpleDateFormat;
+import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Locale;
 import java.util.Set;
 
@@ -577,35 +579,27 @@ MultiPlotGraphic
 		try{
 			this_mon.enter();
 
-			drawScale( sizeChanged );
-
-			if ( bufferScale == null || bufferScale.isDisposed()){
-
-				return;
-			}
-
-			Rectangle bounds = drawCanvas.getClientArea();
-
-			if ( bounds.isEmpty()){
-				return;
-			}
-
-				//If bufferedImage is not null, dispose it
-
-			if (bufferImage != null && !bufferImage.isDisposed()){
-
+			if ( bufferImage != null && !bufferImage.isDisposed()){
+				
 				bufferImage.dispose();
 			}
+			
+		    bufferImage = null;
 
+			Rectangle bounds = drawCanvas.getClientArea();
+			
+			if ( bounds.isEmpty()){
+				
+				return;
+			}
+			
 			bufferImage = new Image(drawCanvas.getDisplay(), bounds);
 
-			gcImage = new GC(bufferImage);
-
-			gcImage.drawImage(bufferScale, 0, 0);
+			gcImage = new GC( bufferImage );
 
 			gcImage.setAntialias( SWT.ON );
 			gcImage.setTextAntialias( SWT.ON );
-
+			
 			Set<ValueSource>	invisible_sources = new HashSet<>();
 
 			for ( int i=0;i<value_sources.length;i++){
@@ -618,6 +612,8 @@ MultiPlotGraphic
 				}
 			}
 
+			List<Object[]>	time_strs = new ArrayList<>();
+			
 			int[] oldTargetValues = new int[all_values.length];
 
 			int[] maxs = new int[all_values.length];
@@ -667,10 +663,8 @@ MultiPlotGraphic
 							if ( xPos >= 0 ){
 							
 								if ( last_xpos < 0 ||  xPos + p.x < last_xpos ){
-								
-									gcImage.setForeground( colorGrey );
-	
-									gcImage.drawText( str, xPos, 0, true );
+									
+									time_strs.add( new Object[]{ str, xPos });
 									
 									last_xpos = xPos;
 								}
@@ -693,10 +687,8 @@ MultiPlotGraphic
 								int xPos = xDraw-p.x/2;
 								
 								if ( xPos >= 0 ){
-								
-									gcImage.setForeground( colorGrey );
-								
-									gcImage.drawText( str, xPos, 0, true );
+																
+									time_strs.add( new Object[]{ str, xPos });
 								}
 							}
 						}
@@ -724,8 +716,9 @@ MultiPlotGraphic
 			Set<ValueSource>	bold_sources = new HashSet<>();
 			Set<ValueSource>	dotted_sources = new HashSet<>();
 
-			int max = 0;
-
+			int max			= 0;
+			int trim_max	= 0;
+			
 			for ( int i=0;i<maxs.length;i++){
 
 				ValueSource source = value_sources[i];
@@ -745,12 +738,21 @@ MultiPlotGraphic
 					dotted_sources.add( source );
 				}
 
-				if ( !source.isTrimmable()){
+				if ( source.isTrimmable()){
 
+					trim_max = Math.max( trim_max, maxs[i] );
+					
+				}else{
+					
 					max = Math.max( max, maxs[i] );
 				}
 			}
 
+			if ( max == 0 ){
+				
+				max = trim_max;
+			}
+			
 			int max_primary = max;
 
 			for ( int i=0;i<maxs.length;i++){
@@ -791,8 +793,32 @@ MultiPlotGraphic
 				max = (( max + kInB - 1 )/kInB)*kInB;
 			}
 
+				// got to set the max before creating scale otherwise we miss a cycle...
+			
 			scale.setMax( max );
+			
+			drawScale(sizeChanged);
 
+			if ( bufferScale == null || bufferScale.isDisposed()){
+				
+				return;
+			}
+	
+		    gcImage.drawImage(bufferScale,0,0);
+
+		    if ( !time_strs.isEmpty()){
+		    	
+				gcImage.setForeground( colorGrey );
+	
+			    for ( Object[] entry: time_strs ){
+			    	
+			    	String	str		= (String)entry[0];
+			    	int		xPos	= (Integer)entry[1];
+			    	
+					gcImage.drawText( str, xPos, 0, true );
+			    }
+		    }
+		    
 			int[]	prev_x = new int[value_sources.length];
 			int[]	prev_y = new int[value_sources.length];
 
@@ -940,29 +966,36 @@ MultiPlotGraphic
 							
 							if ( show_label ){
 
-								int	average_val = computeAverage( chartIdx, currentPosition - 6 );
+								int position = currentPosition-1;
+								
+								if ( position < 0 ){
 
-								int average_mod = average_val;
+									position += maxEntries;
+								}
+								
+								int	last_val = all_values[chartIdx][ position ];
 
-								if ( average_mod > max ){
+								int last_mod = last_val;
 
-									average_mod = max;
+								if ( last_mod > max ){
+
+									last_mod = max;
 								}
 
-								int height = bounds.height - scale.getScaledValue( average_mod) - 2;
+								int height = bounds.height - scale.getScaledValue( last_mod) - 2;
 
 								gcImage.setAlpha( 255 );
 
 								gcImage.setForeground( source.getLineColor());
 
-								gcImage.drawText(formater.format( average_val ), bounds.width - 65, height - 12, SWT.DRAW_TRANSPARENT);
+								gcImage.drawText(formater.format( last_mod ), bounds.width - 65, height - 12, SWT.DRAW_TRANSPARENT);
 
 								Color bg = gcImage.getBackground();
 
 								if (( style & ValueSource.STYLE_DOWN ) != 0 ){
 
 									int	x = bounds.width - 72;
-									int y = height - 12;
+									int y = height-3;
 
 									gcImage.setBackground( source.getLineColor());
 
@@ -973,7 +1006,7 @@ MultiPlotGraphic
 								}else  if (( style & ValueSource.STYLE_UP ) != 0 ){
 
 									int	x = bounds.width - 72;
-									int y = height - 12;
+									int y = height - 3;
 
 									gcImage.setBackground( source.getLineColor());
 
@@ -984,7 +1017,7 @@ MultiPlotGraphic
 								}else  if (( style & ValueSource.STYLE_BLOB ) != 0 ){
 
 									int	x = bounds.width - 72;
-									int y = height - 12;
+									int y = height - 3;
 
 									gcImage.setBackground( source.getLineColor());
 
@@ -1012,23 +1045,6 @@ MultiPlotGraphic
 		}
 	}
 
-	private int
-	computeAverage(
-		int	line_index,
-		int position )
-	{
-		long sum = 0;
-		for(int i = -5 ; i < 6 ; i++) {
-			int pos = position + i;
-			pos %= maxEntries;
-			if (pos < 0)
-				pos += maxEntries;
-			sum += all_values[line_index][pos];
-		}
-		return(int)(sum / 11);
-
-	}
-
 	@Override
 	public void
 	parameterChanged(
