@@ -142,7 +142,7 @@ public class MultiTrackerEditor {
 
 	    addTemplates();
 	    
-	    Label labelSeparator = new Label(shell,SWT.SEPARATOR | SWT.HORIZONTAL);
+	    Control labelSeparator = Utils.createSkinnedLabelSeparator(shell,SWT.HORIZONTAL);
 	    GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
 	    gridData.horizontalSpan = 3;
 	    labelSeparator.setLayoutData(gridData);
@@ -257,7 +257,7 @@ public class MultiTrackerEditor {
     }
 
 
-    Label labelSeparator = new Label(shell,SWT.SEPARATOR | SWT.HORIZONTAL);
+    Control labelSeparator =  Utils.createSkinnedLabelSeparator( shell, SWT.HORIZONTAL);
     gridData = new GridData(GridData.FILL_HORIZONTAL);
     gridData.horizontalSpan = 3;
     labelSeparator.setLayoutData(gridData);
@@ -915,7 +915,7 @@ public class MultiTrackerEditor {
       public void handleEvent (Event e) {
       	String url = text.getText();
       	if ( validURL(url)){
-      		text.setForeground( null );
+      		Utils.setSkinnedForeground( text, null );
       		item.setForeground( null );
       	}else{
       		text.setForeground( Colors.colorError );
@@ -932,7 +932,7 @@ public class MultiTrackerEditor {
 	    public void handleEvent (Event e) {
     		String url = text.getText();
     		if ( validURL(url)){
-    			text.setForeground( null );
+    			Utils.setSkinnedForeground( text, null );
     			item.setForeground( null );
     		}else{
     			text.setForeground( Colors.colorError );
