@@ -160,6 +160,26 @@ public abstract class BaseMdiEntry
 		}
 	}
 
+	public boolean
+	canClose(
+		boolean userInitiated )
+	{
+		MdiCloseListener[] list = {};
+		synchronized (this) {
+			if (listCloseListeners != null) {
+				list = listCloseListeners.toArray(new MdiCloseListener[0]);
+			}
+		}		
+		
+		for (MdiCloseListener l : list) {
+			if ( !l.midEntryCanClose( this, userInitiated )){
+				return( false );
+			}
+		}
+		
+		return( true );
+	}
+	
 	@Override
 	public boolean close(boolean forceClose) {
 		closeView();
@@ -584,14 +604,16 @@ public abstract class BaseMdiEntry
 			ViewTitleInfoManager.addListener(this);
 
 			if (getEventListener() == null && (viewTitleInfo instanceof UISWTViewEventListener)) {
-				if (getSkinRef() == null) {
-					// TODO Remove this debug
-					System.out.println(
+				UISWTViewEventListener listener = (UISWTViewEventListener) viewTitleInfo;
+				
+				if (getSkinRef() == null && !listener.builderNotRequired()){
+					
+					Debug.out(
 							"Setting event listener because viewTitleInfo instance of UISWTViewEventListener.  Might lose builder info. "
 									+ getViewID() + " via " + Debug.getCompressedStackTrace());
 				}
 				try {
-					setEventListener((UISWTViewEventListener) viewTitleInfo, null, true);
+					setEventListener(listener, null, true);
 				} catch (UISWTViewEventCancelledException ignore) {
 				}
 			}
@@ -1386,6 +1408,11 @@ public abstract class BaseMdiEntry
 			data_source = getUserData( UD_STANDALONE_DATA_SOURCE );
 		}
 		
+		if ( data_source == null ){
+			
+			data_source = getInitialDataSource();
+		}
+		
 		return(
 			buildStandAlone(
 				soParent,
