@@ -21,7 +21,6 @@
 package com.biglybt.ui.swt.plugin.net.buddy.swt;
 
 import java.net.InetSocketAddress;
-import java.text.SimpleDateFormat;
 import java.util.List;
 import java.util.*;
 
@@ -66,13 +65,14 @@ import com.biglybt.ui.UIFunctions;
 import com.biglybt.ui.UIFunctionsManager;
 import com.biglybt.ui.UserPrompterResultListener;
 import com.biglybt.ui.swt.Messages;
+import com.biglybt.ui.swt.PropertiesWindow;
+import com.biglybt.ui.swt.TextViewerWindow;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.components.LinkLabel;
 import com.biglybt.ui.swt.config.IntSwtParameter;
 import com.biglybt.ui.swt.imageloader.ImageLoader;
 import com.biglybt.ui.swt.mainwindow.ClipboardCopy;
 import com.biglybt.ui.swt.mainwindow.Colors;
-import com.biglybt.ui.swt.plugin.net.buddy.*;
 import com.biglybt.ui.swt.shells.MessageBoxShell;
 import com.biglybt.ui.swt.utils.TagUIUtilsV3;
 
@@ -109,6 +109,7 @@ BuddyPluginViewInstance
 	private CTabFolder  		tab_folder;
 	
 	private CTabItem 			classic_item;
+	private CTabItem 			chat_item;
 
 	private boolean				classic_enabled;
 	private boolean				beta_enabled;
@@ -149,9 +150,9 @@ BuddyPluginViewInstance
 		GridData grid_data = new GridData(GridData.FILL_BOTH);
 		tab_folder.setLayoutData(grid_data);
 
-		CTabItem beta_item = new CTabItem(tab_folder, SWT.NULL);
+		chat_item = new CTabItem(tab_folder, SWT.NULL);
 
-		beta_item.setText( lu.getLocalisedMessageText( "azbuddy.dchat.decentralized" ));
+		chat_item.setText( lu.getLocalisedMessageText( "azbuddy.dchat.decentralized" ));
 
 		ScrolledComposite beta_area = new ScrolledComposite( tab_folder, SWT.V_SCROLL | SWT.H_SCROLL );
 		
@@ -160,7 +161,7 @@ BuddyPluginViewInstance
 
 		beta_area.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
 
-		beta_item.setControl( beta_area );
+		chat_item.setControl( beta_area );
 				
 		Composite beta_area_comp = new Composite( beta_area, SWT.NULL );
 				
@@ -228,7 +229,7 @@ BuddyPluginViewInstance
 		
 		int sel = COConfigurationManager.getIntParameter( "buddy.plugin.ui.selected.tab", 0 );
 		
-		tab_folder.setSelection(sel==0?beta_item:classic_item);
+		tab_folder.setSelection(sel==0?chat_item:classic_item);
 		
 		tab_folder.addSelectionListener(
 			new SelectionAdapter(){
@@ -246,16 +247,15 @@ BuddyPluginViewInstance
 	protected void
 	selectClassicTab()
 	{
-		Utils.execSWTThread(
-			new Runnable() {
-
-				@Override
-				public void run() {
-					tab_folder.setSelection( classic_item );
-				}
-			});
+		Utils.execSWTThread(()->tab_folder.setSelection( classic_item ));
 	}
 
+	protected void
+	selectChatTab()
+	{
+		Utils.execSWTThread(()->tab_folder.setSelection( chat_item ));;
+	}
+	
 	private void
 	createBeta(
 		Composite main )
@@ -1901,7 +1901,7 @@ BuddyPluginViewInstance
 				"azbuddy.ui.table.ss" };
 
 		int[] sizes = {
-			250, 100, 100, 100, 200,
+			250, 75, 130, 50, 200,
 			100, 100, 100, 75, 75,
 			75, 75, 75, 75, 75,
 			40 };
@@ -2018,11 +2018,11 @@ BuddyPluginViewInstance
 
 					long lo = buddy.getLastTimeOnline();
 
-					item.setText(2, lo==0?"":new SimpleDateFormat().format(new Date( lo )));
+					item.setText(2, lo==0?"":DisplayFormatters.formatDateYMDHM( lo ));
 
 					long	last_ygm = buddy.getLastMessagePending();
 
-					item.setText(3, last_ygm==0?"":new SimpleDateFormat().format(new Date( last_ygm )));
+					item.setText(3, last_ygm==0?"":DisplayFormatters.formatDateYMDHM( last_ygm ));
 
 					String	lm = buddy.getLastMessageReceived();
 
@@ -3059,7 +3059,28 @@ BuddyPluginViewInstance
 				}
 			});
 
+		new MenuItem( menu, SWT.SEPARATOR );
 
+		MenuItem properties_item = new MenuItem(menu, SWT.PUSH);
+
+		properties_item.setText( lu.getLocalisedMessageText( "label.properties" ));
+			
+		properties_item.addListener( SWT.Selection, (ev)->{
+			
+			TableItem[] selection = buddy_table.getSelection();
+
+			BuddyPluginBuddy buddy = (BuddyPluginBuddy)selection[0].getData();
+			
+			String text = buddy.getProperties();
+			
+			TextViewerWindow viewer =
+					new TextViewerWindow(
+						composite.getShell(),
+						"label.properties",
+						null, text, false, false );
+			
+		});
+		
 			// done with menus
 
 		buddy_table.setMenu( menu );
@@ -3093,6 +3114,7 @@ BuddyPluginViewInstance
 					verify_item.setEnabled(true);
 					cat_item.setEnabled(selection.length > 0);
 					set_name_item.setEnabled( selection.length == 1);
+					properties_item.setEnabled(selection.length == 1);
 				}
 
 				@Override
