@@ -18,7 +18,6 @@ package com.biglybt.ui.swt.shells.main;
 
 import java.io.File;
 import java.net.URL;
-import java.text.SimpleDateFormat;
 import java.util.List;
 import java.util.*;
 
@@ -32,6 +31,7 @@ import org.eclipse.swt.widgets.*;
 import com.biglybt.core.Core;
 import com.biglybt.core.CoreFactory;
 import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ConfigKeys;
 import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.config.impl.ConfigurationDefaults;
 import com.biglybt.core.download.DownloadManager;
@@ -47,6 +47,7 @@ import com.biglybt.core.proxy.AEProxyFactory;
 import com.biglybt.core.proxy.AEProxyFactory.PluginHTTPProxy;
 import com.biglybt.core.torrent.PlatformTorrentUtils;
 import com.biglybt.core.torrent.TOTorrent;
+import com.biglybt.core.torrent.TOTorrentFile;
 import com.biglybt.core.torrent.impl.TorrentOpenOptions;
 import com.biglybt.core.util.*;
 import com.biglybt.core.vuzefile.VuzeFileHandler;
@@ -91,7 +92,7 @@ import com.biglybt.ui.swt.views.skin.SkinnedDialog.SkinnedDialogClosedListener;
 import com.biglybt.ui.swt.views.skin.sidebar.SideBarEntrySWT;
 import com.biglybt.ui.swt.views.table.TableCellSWTPaintListener;
 import com.biglybt.ui.swt.views.utils.ManagerUtils;
-
+import com.biglybt.util.PlayUtils;
 import com.biglybt.pif.download.DownloadStub;
 import com.biglybt.pif.ui.UIInputReceiver;
 import com.biglybt.pif.ui.UIInputReceiverListener;
@@ -736,35 +737,39 @@ public class UIFunctionsImpl
 
 		}else if ( action_id == ACTION_UPDATE_RESTART_REQUEST ){
 
-			String title = MessageText.getString("UpdateMonitor.messagebox.restart.title" );
-
-			String text = MessageText.getString("UpdateMonitor.messagebox.restart.text" );
-
-			bringToFront();
-
-			boolean no_timeout = args instanceof Boolean && ((Boolean)args).booleanValue();
-
-			int timeout = 180000;
-
-			if ( no_timeout || !PluginInitializer.getDefaultInterface().getPluginManager().isSilentRestartEnabled()){
-
-				timeout = -1;
-			}
-
-			MessageBoxShell messageBoxShell = new MessageBoxShell(title, text,
-					new String[] {
-				MessageText.getString("UpdateWindow.restart"),
-				MessageText.getString("UpdateWindow.restartLater")
-			}, 0);
-			messageBoxShell.setAutoCloseInMS(timeout);
-			messageBoxShell.setParent(getMainShell());
-			messageBoxShell.setOneInstanceOf("UpdateMonitor.messagebox.");
-			messageBoxShell.open( new UserPrompterResultListener() {
-				@Override
-				public void prompterClosed(int result) {
-					listener.actionComplete(result == 0);
-				}
-			});
+			Utils.runWhenCoreOperationsIdle(
+				CoreFactory.getSingleton(),
+				()->{
+					String title = MessageText.getString("UpdateMonitor.messagebox.restart.title" );
+		
+					String text = MessageText.getString("UpdateMonitor.messagebox.restart.text" );
+		
+					bringToFront();
+		
+					boolean no_timeout = args instanceof Boolean && ((Boolean)args).booleanValue();
+		
+					int timeout = 180000;
+		
+					if ( no_timeout || !PluginInitializer.getDefaultInterface().getPluginManager().isSilentRestartEnabled()){
+		
+						timeout = -1;
+					}
+		
+					MessageBoxShell messageBoxShell = new MessageBoxShell(title, text,
+							new String[] {
+						MessageText.getString("UpdateWindow.restart"),
+						MessageText.getString("UpdateWindow.restartLater")
+					}, 0);
+					messageBoxShell.setAutoCloseInMS(timeout);
+					messageBoxShell.setParent(getMainShell());
+					messageBoxShell.setOneInstanceOf("UpdateMonitor.messagebox.");
+					messageBoxShell.open( new UserPrompterResultListener() {
+						@Override
+						public void prompterClosed(int result) {
+							listener.actionComplete(result == 0);
+						}
+					});
+				});
 		}else{
 
 			Debug.out( "Unknown action " + action_id );
@@ -1428,37 +1433,45 @@ public class UIFunctionsImpl
 					Debug.out( e );
 				}
 
-				if ( !is_silent ){
+				try{
+					DownloadHistoryManager dlm = (DownloadHistoryManager)core.getGlobalManager().getDownloadHistoryManager();
 
-					try{
-						DownloadHistoryManager dlm = (DownloadHistoryManager)core.getGlobalManager().getDownloadHistoryManager();
-
-						final long[] existing = dlm.getDates( torrentOptions.getTorrent().getHash(), true);
+					final long[] existing = dlm.getDates( torrentOptions.getTorrent().getHash(), true);
 
+					if ( !is_silent ){	
+	
 						if ( existing != null ){
-
+	
 							long	redownloaded = existing[3];
-
+	
 							if ( SystemTime.getCurrentTime() - redownloaded > 60*10*1000 ){
-
+	
 								if ( getVisibilityState() != VS_TRAY_ONLY){
-
+	
 									forceNotify(STATUSICON_NONE,
 										MessageText.getString(
 											"OpenTorrentWindow.mb.inHistory.title"),
 										MessageText.getString(
 											"OpenTorrentWindow.mb.inHistory.text", new String[] {
 												torrentOptions.getTorrentName(),
-												new SimpleDateFormat().format( new Date( existing[0] ))
+												DisplayFormatters.formatDateYMDHM( existing[0] )
 											}), null, new Object[0], -1);
-
+	
 								}
 							}
 						}
-					}catch( Throwable e ){
-
-						Debug.out( e );
 					}
+					
+					if ( dlm.isEnabled() && COConfigurationManager.getBooleanParameter( ConfigKeys.File.BCFG_DOWNLOAD_HISTORY_DONT_ADD_DUP )){
+												
+						if ( existing != null && existing[1] > 0 ){
+							
+							return( true );
+						}
+					}
+				}catch( Throwable e ){
+					
+					Debug.out( e );
 				}
 			}
 		}
@@ -1471,8 +1484,62 @@ public class UIFunctionsImpl
 		TorrentOpenOptions 		torrentOptions,
 		Map<String, Object> 	addOptions,
 		boolean					is_silent )
-
 	{
+		TOTorrent torrent = torrentOptions.getTorrent();
+
+		if ( torrent != null ){
+			
+			String name = TorrentUtils.getLocalisedName(torrent);
+			
+			TOTorrentFile[] files = torrent.getFiles();
+			
+			if ( files.length == 1 ){
+				
+				String file_name = files[0].getRelativePath();
+				
+				if ( !file_name.equals(name)){
+					
+					int n_pos = name.lastIndexOf( "." );
+					int f_pos = file_name.lastIndexOf( "." );
+					
+					if ( n_pos != -1 && f_pos != -1 ){
+						
+						String n_ext = name.substring( n_pos+1 ).trim().toLowerCase( Locale.US );
+						String f_ext = file_name.substring( f_pos+1 ).trim().toLowerCase( Locale.US );
+						
+						if ( 	!f_ext.isEmpty() && 
+								!n_ext.equals( f_ext ) &&
+								!PlayUtils.getPlayableFileExtensions().contains(f_ext)){
+							
+							UIFunctionsUserPrompter prompter = 
+								getUserPrompter(
+									MessageText.getString( "msg.suspicious.file.name" ),
+									MessageText.getString( "msg.suspicious.file.name.info", new String[]{ name, n_ext, f_ext }),
+									new String[] {
+										MessageText.getString("Button.ok"),
+									}, 
+									0 );
+			
+							prompter.setStyle( SWT.ON_TOP );
+							
+							prompter.setRemember(
+								"oto:suspicious.torrent",
+								false,
+								MessageText.getString("MessageBoxWindow.nomoreprompting"));
+							
+			
+							prompter.setIconResource("warning");
+							
+							prompter.setAutoCloseInMS(0);
+			
+							prompter.open(null);
+						}
+					}
+				}
+			}
+		}
+		
+		
 		Boolean force = (Boolean)addOptions.get( UIFunctions.OTO_FORCE_OPEN );
 
 		if ( force == null ){
@@ -1482,8 +1549,6 @@ public class UIFunctionsImpl
 
 		if ( !force ){
 
-			TOTorrent torrent = torrentOptions.getTorrent();
-
 			boolean is_featured = torrent != null && PlatformTorrentUtils.isFeaturedContent( torrent );
 
 			String showAgainMode = COConfigurationManager.getStringParameter(ConfigurationDefaults.CFG_TORRENTADD_OPENOPTIONS);
