@@ -727,7 +727,8 @@ public class SWTSkinObjectBasic
 				}
 
 				Color fg = getColor_SuffixWalkback(sConfigID + ".fgcolor");
-				control.setForeground(fg);
+				
+				Utils.setSkinnedForeground( control, fg );
 
 				// Color,[width]
 				String sBorderStyle = properties.getStringValue(sConfigID + ".border"
