@@ -1173,6 +1173,13 @@ SubscriptionManagerUI
 
 						cell.setSortValue( 0 );
 					}
+					
+					TableColumn tableColumn = cell.getTableColumn();
+					
+					if ( tableColumn != null && tableColumn.getPreferredWidth() < 32 ){
+					
+						cell.getTableColumn().setPreferredWidth( 32 );
+					}
 				}
 			};
 
@@ -1676,8 +1683,6 @@ SubscriptionManagerUI
 	{
 		if (!subs.isSubscribed()){
 
-				// user may have deleted subscrtipion, but our register is staill there
-
 			return null;
 		}
 
@@ -1706,7 +1711,7 @@ SubscriptionManagerUI
 		name_map.put( subs_name, key );
 
 		MdiEntry[] existing = mdi.getEntries();
-
+		
 		for ( MdiEntry e: existing ){
 
 			String id = e.getViewID();
@@ -1828,12 +1833,14 @@ SubscriptionManagerUI
 							null,
 							parent_name,
 							parent, null, false, parent_prev_id );
+					
+					parent_views.put( parent_name, parent_entry );
 				}
 			}
 
 			entry = mdi.createEntry(new UISWTViewBuilderCore(key, null,
 					SubscriptionView.class).setParentEntryID(
-							parent_entry.getViewID()).setInitialDatasource(subs),
+							parent_entry.getViewID()).setInitialDatasource(subs).setPreferredAfterID(prev_id),
 					true);
 		}
 
@@ -2038,6 +2045,8 @@ SubscriptionManagerUI
 					.getScheduler()
 					.downloadAsync(sub, true));
 
+			menu_creator.newSeparator();
+			
 			menu_creator.newItem("Subscription.menu.clearall",
 				(SelectionList_NoTemplates) (subs) -> {
 					for (Subscription sub : subs) {
@@ -2984,8 +2993,6 @@ SubscriptionManagerUI
 	{
 		SubscriptionHistory history = subs.getHistory();
 
-		SimpleDateFormat df = new SimpleDateFormat();
-
 		String last_error = history.getLastError();
 
 		if ( last_error == null ){
@@ -3063,7 +3070,14 @@ SubscriptionManagerUI
 		int	 check_freq			= history.getCheckFrequencyMins();
 		long last_new_result 	= history.getLastNewResultTime();
 		long next_scan 			= history.getNextScanTime();
-
+		
+		long next_sched = history.getNextScheduledUpdate();
+		
+		if ( next_sched> 0 ){
+			
+			next_scan = next_sched;
+		}
+		
 		int max_results = history.getMaxNonDeletedResults();
 
 		if ( max_results < 0 ){
@@ -3082,10 +3096,10 @@ SubscriptionManagerUI
 				String.valueOf( subs.isAutoDownloadSupported()),
 				String.valueOf( history.getDownloadNetworks() != null ),
 				(check_freq==Integer.MAX_VALUE?"":(String.valueOf( history.getCheckFrequencyMins() + " " + MessageText.getString( "ConfigView.text.minutes")))),
-				df.format(new Date( history.getLastScanTime())),
-				( last_new_result==0?"":df.format(new Date( last_new_result ))),
-				( next_scan == Long.MAX_VALUE?"":df.format(new Date( next_scan ))),
-				(last_error.length()==0?MessageText.getString("label.none"):last_error),
+				DisplayFormatters.formatDateYMDHM( history.getLastScanTime()),
+				( last_new_result==0?"":DisplayFormatters.formatDateYMDHM( last_new_result )),
+				( next_scan == Long.MAX_VALUE?"":DisplayFormatters.formatDateYMDHM( next_scan )),
+				(last_error.length()==0?MessageText.getString("label.none"):( DisplayFormatters.formatDateYMDHM(history.getLastErrorTime())+ ": " +last_error)),
 				String.valueOf( history.getNumRead()),
 				String.valueOf( history.getNumUnread()),
 				max_results_str,
@@ -3218,17 +3232,19 @@ SubscriptionManagerUI
 
 				if (!input.isEmpty()) {
 
-					try {
-						WebEngine web_engine1 = (WebEngine) sub.getEngine();
-
-						web_engine1.setSearchUrl(input);
-
-						sub.cloneWithNewEngine(web_engine1);
-
-					} catch (Throwable e) {
-
-						Debug.out(e);
-					}
+					Utils.getOffOfSWTThread(()->{
+						try {
+							WebEngine web_engine1 = (WebEngine) sub.getEngine();
+	
+							web_engine1.setSearchUrl(input);
+	
+							sub.cloneWithNewEngine(web_engine1);
+	
+						} catch (Throwable e) {
+	
+							Debug.out(e);
+						}
+					});
 				}
 			});
 		} catch (Throwable e) {
@@ -3561,6 +3577,13 @@ SubscriptionManagerUI
 			title = _title;
 		}
 
+		@Override
+		public boolean 
+		builderNotRequired()
+		{
+			return( true );	// suppress warning about builder possibly being lost
+		}
+		
 		public String
 		getTitle()
 		{
