@@ -112,8 +112,25 @@ public abstract class InfoBarUtil
 		}
 		FormData fdForSO = (FormData) ldForSO;
 		SWTSkinObjectContainer parent = (SWTSkinObjectContainer)forSO.getParent();
-		soInfoBar = skin.createSkinObject(skintemplateid + (uniqueNo++), skintemplateid, parent);
 
+			// this isn't skinned in dark mode at the moment
+		
+		boolean disable_skinning = Utils.isDarkAppearanceNative();
+		
+		try{
+			if ( disable_skinning ){
+				
+				Utils.setSkinningEnabled( false );
+			}
+			
+			soInfoBar = skin.createSkinObject(skintemplateid + (uniqueNo++), skintemplateid, parent);
+		}finally{
+			
+			if ( disable_skinning ){
+				
+				Utils.setSkinningEnabled( true );
+			}
+		}
 		FormData fdInfoBar = (FormData) soInfoBar.getControl().getLayoutData();
 		if (fdInfoBar == null) {
 			fdInfoBar = Utils.getFilledFormData();
