@@ -21,6 +21,7 @@
 package com.biglybt.ui.swt.views.skin;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.regex.Pattern;
@@ -62,7 +63,6 @@ import com.biglybt.ui.swt.components.BubbleTextBox;
 import com.biglybt.ui.swt.mainwindow.MenuFactory;
 import com.biglybt.ui.swt.mdi.MdiEntrySWT;
 import com.biglybt.ui.swt.mdi.MultipleDocumentInterfaceSWT;
-import com.biglybt.ui.swt.pif.UISWTView;
 import com.biglybt.ui.swt.pifimpl.UISWTViewBuilderCore;
 import com.biglybt.ui.swt.pifimpl.UISWTViewCore;
 import com.biglybt.ui.swt.skin.*;
@@ -106,7 +106,7 @@ public class SBC_TagsOverview
 	private boolean tm_listener_added;
 	private boolean gm_listener_added;
 	
-	private Object datasource;
+	private List<Tag> datasources_for_selection = new ArrayList<>();
 
 	private boolean show_swarm_tags;
 	
@@ -578,14 +578,38 @@ public class SBC_TagsOverview
 					}
 				});
 		
-		tableManager.registerColumn(Tag.class, ColumnTagsSortAutoApply.COLUMN_ID,
+		tableManager.registerColumn(Tag.class, ColumnTagSortAutoApply.COLUMN_ID,
 				new TableColumnCreationListener() {
 					@Override
 					public void tableColumnCreated(TableColumn column) {
-						new ColumnTagsSortAutoApply(column);
+						new ColumnTagSortAutoApply(column);
+					}
+				});
+		
+		tableManager.registerColumn(Tag.class, ColumnTagHideWhenEmpty.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnTagHideWhenEmpty(column);
 					}
 				});
 
+		tableManager.registerColumn(Tag.class, ColumnTagMaxActiveDownloads.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnTagMaxActiveDownloads(column);
+					}
+				});
+		
+		tableManager.registerColumn(Tag.class, ColumnTagMaxActiveSeeds.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnTagMaxActiveSeeds(column);
+					}
+				});
+		
 		tableManager.setDefaultColumnNames(TABLE_TAGS,
 				new String[] {
 					ColumnTagColor.COLUMN_ID,
@@ -607,6 +631,15 @@ public class SBC_TagsOverview
 	@Override
 	public Object skinObjectHidden(SWTSkinObject skinObject, Object params) {
 
+		datasources_for_selection.clear();
+		
+		List<Object> dataSources = tv.getSelectedDataSources();
+		for (Object dataSource : dataSources) {
+			if ((dataSource instanceof Tag)){
+				datasources_for_selection.add((Tag)dataSource);
+			}
+		}
+
 		if (tv != null) {
 
 			tv.delete();
@@ -747,6 +780,11 @@ public class SBC_TagsOverview
 			layout.marginHeight = layout.marginWidth = layout.verticalSpacing = layout.horizontalSpacing = 0;
 			table_parent.setLayout(layout);
 
+			/*
+			 * 05/2024. Removed this because re-activation is causing selected content to be lost. In this case select a tag, select the Torrents sub-view
+			 * and select a torrent. Hit F2 for example (to get a change-name dialog) and then hit escape to close the dialog. With this code enabled it causes
+			 * selection to return to the Tag above rather than the torrent
+			 * 
 			table_parent.addListener(SWT.Activate, new Listener() {
 				@Override
 				public void handleEvent(Event event) {
@@ -754,6 +792,7 @@ public class SBC_TagsOverview
 					updateSelectedContent();
 				}
 			});
+			*/
 			/*
 			table_parent.addListener(SWT.Deactivate, new Listener() {
 				public void handleEvent(Event event) {
@@ -779,8 +818,13 @@ public class SBC_TagsOverview
 
 				@Override
 				public void rowAdded(TableRowCore row) {
-					if (datasource == row.getDataSource()) {
-						tv.setSelectedRows(new TableRowCore[] { row });
+					if ( datasources_for_selection.remove( row.getDataSource())) {
+						List<TableRowCore> rows = Arrays.asList(tv.getSelectedRows());
+						if ( !rows.contains( row )){
+							rows = new ArrayList<>( rows );
+							rows.add( row );
+							tv.setSelectedRows( rows.toArray( new TableRowCore[rows.size()]));
+						}
 					}
 				}
 			});
@@ -1448,15 +1492,17 @@ public class SBC_TagsOverview
 	// @see SWTSkinObjectAdapter#dataSourceChanged(SWTSkinObject, java.lang.Object)
 	@Override
 	public Object dataSourceChanged(SWTSkinObject skinObject, Object params) {
+		datasources_for_selection.clear();
 		if (params instanceof Tag) {
+			Tag tag = (Tag)params;
+			datasources_for_selection.add(tag);
 			if (tv != null) {
-				TableRowCore row = tv.getRow((Tag) params);
+				TableRowCore row = tv.getRow( tag );
 				if (row != null) {
 					tv.setSelectedRows(new TableRowCore[] { row });
 				}
 			}
 		}
-		datasource = params;
 		return null;
 	}
 
