@@ -815,8 +815,13 @@ public class NameItem extends CoreTableColumnSWT implements
 
 			
 			@Override
-			public void run(CoreOperation operation) {
+			public boolean 
+			runOperation(
+				CoreOperation operation) 
+			{
 				result[0] = fileInfo.setLink( target, false );
+				
+				return( true );
 			}
 
 			@Override
