@@ -70,10 +70,14 @@ public class SizeItem
     	
     	text = "";
     	
+    	cell.setNumeric( Double.NaN );
+    	
     }else{
     	
     	text = DisplayFormatters.formatByteCountToKiBEtc(value);
     	
+    	cell.setNumeric( value );
+    	
     	if ( internal ){
     		
     		//text = "(" + text + ")";
