@@ -334,10 +334,7 @@ public class TagColorsItem
 
 			Rectangle bounds = cell.getBounds();
 
-			bounds.x+=1;
-			bounds.y+=1;
-			bounds.width-=1;
-			bounds.height-=1;
+			Utils.setClipping(gc, new Rectangle( bounds.x, bounds.y+1, bounds.width-1, bounds.height-2 ));
 
 			if ( num_colors == 1 ){
 
